pub fn scan(program: &Program) -> RequiredCapabilitiesExpand description
Walk the program and collect the union of capabilities it requires.
pub fn scan(program: &Program) -> RequiredCapabilitiesWalk the program and collect the union of capabilities it requires.