pub struct ScanDatabaseSectionHeader {
pub kind: ScanDatabaseSectionKind,
pub offset: u64,
pub byte_len: u64,
pub section_digest: u64,
}Expand description
Locator and integrity digest for one table section in the database body.
Fields
kind: ScanDatabaseSectionKindKind of payload this section carries.
offset: u64Byte offset of the section payload from the start of the database body.
byte_len: u64Byte length of the section payload.
section_digest: u64Integrity digest over the section payload bytes.